<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://davidstockdalescrapcode.co.uk
 * @since      1.0.0
 *
 * @package    David_Scroller
 * @subpackage David_Scroller/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    David_Scroller
 * @subpackage David_Scroller/admin
 * @author     David Stockdale <davidstockdale13@hotmail.co.uk>
 */
class David_Scroller_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $david_scroller    The ID of this plugin.
	 */
	private $david_scroller;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	
	/**
	 * The options name to be used in this plugin
	 *
	 * @since  	1.0.0
	 * @access 	private
	 * @var  	string 		$option_name 	Option name of this plugin
	 */
	private $option_name = 'david_scroller';

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $david_scroller       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $david_scroller, $version ) {

		$this->david_scroller = $david_scroller;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in David_Scroller_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The David_Scroller_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->david_scroller, plugin_dir_url( __FILE__ ) . 'css/david-scroller-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in David_Scroller_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The David_Scroller_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->david_scroller, plugin_dir_url( __FILE__ ) . 'js/david-scroller-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	
	
	
	
	
	
	/**
	 * Add an options page under the Settings submenu
	 *
	 * @since  1.0.0
	 */
	public function add_options_page() {
	
		$this->plugin_screen_hook_suffix = add_options_page(
			__( 'David Scroller Settings', 'david-scroller' ),
			__( 'David Scroller', 'david-scroller' ),
			'manage_options',
			$this->david_scroller,
			array( $this, 'display_options_page' )
		);
	
	}
	
	
	/**
	 * Render the options page for plugin
	 *
	 * @since  1.0.0
	 */
	public function display_options_page() {
		include_once 'partials/david-scroller-admin-display.php';
	}

	
	
	
	public function register_setting() {
		
		add_settings_section(
		$this->option_name . '_general',
		__( 'General', 'david-scroller' ),
		array( $this, $this->option_name . '_general_cb' ),
		$this->david_scroller);
		
		
// 		add_settings_field(
// 		$this->option_name . '_position',
// 		__( 'Text position', 'david-scroller' ),
// 		array( $this, $this->option_name . '_position_cb' ),
// 		$this->david_scroller,
// 		$this->option_name . '_general',
// 		array( 'label_for' => $this->option_name . '_position' ));
		
		
		add_settings_field(
		$this->option_name . '_key',
		__( 'Add API Key:', 'david-scroller' ),
		array( $this, $this->option_name . '_key_cb' ),
		$this->david_scroller,
		$this->option_name . '_general',
		array( 'label_for' => $this->option_name . '_key' ));
		
		
		add_settings_field(
		$this->option_name . '_spreadsheet',
		__( 'Add SpreadSheet ID:', 'david-scroller' ),
		array( $this, $this->option_name . '_spreadsheet_cb' ),
		$this->david_scroller,
		$this->option_name . '_general',
		array( 'label_for' => $this->option_name . '_spreadsheet' ));
		
		
// 		register_setting( $this->plugin_name, $this->option_name . '_position', array( $this, $this->option_name . '_sanitize_position' ) );
		
		
		
		//register_setting( $this->plugin_name, $this->option_name . '_key', 'string' );
		
		register_setting( $this->david_scroller, $this->option_name . '_key', array( $this, $this->option_name . '_sanitize_key' ) );
		
		
		register_setting( $this->david_scroller, $this->option_name . '_spreadsheet', array( $this, $this->option_name . '_sanitize_spreadsheet' ) );
		
		
	}
	
	/**
	 * Render the treshold day input for this plugin
	 *
	 * @since  1.0.0
	 */
	public function david_scroller_spreadsheet_cb() {
		echo '<input type="text" name="' . $this->option_name . '_spreadsheet' . '" id="' . $this->option_name . '_spreadsheet' . '"> ';
		
		$spreadsheet = get_option( $this->option_name . '_spreadsheet' );
		
		$options = get_option( $this->option_name . '_spreadsheet' );
		var_dump($options);
		
	}
	
	
	/**
	 * Sanitize the text position value before being saved to database
	 *
	 * @param  string $position $_POST value
	 * @since  1.0.0
	 * @return string           Sanitized value
	 */
	public function david_scroller_sanitize_spreadsheet( $spreadsheet ) {
		$options = get_option( $this->option_name . '_spreadsheet' );
		if(!empty($spreadsheet)) {
			array_push($options, $spreadsheet);
		}
		
		return $options;
		
	}
	
	
	
	/**
	 * Sanitize the text position value before being saved to database
	 *
	 * @param  string $position $_POST value
	 * @since  1.0.0
	 * @return string           Sanitized value
	 */
	public function david_scroller_sanitize_key( $key ) {
		$options = get_option( $this->option_name . '_key' );
		if(!empty($key)) {
			array_push($options, $key);
		}
		
		return $options;
		
	}
	
	
	
	/**
	 * Render the text for the general section
	 *
	 * @since  1.0.0
	 */
	public function david_scroller_general_cb() {
		echo '<p>' . __( 'Please change the settings accordingly.', 'david-scroller' ) . '</p>';
	}
	
	
	/**
	 * Render the radio input field for position option
	 *
	 * @since  1.0.0
	 *
	public function david_scroller_position_cb() {
		?>
			<fieldset>
				<label>
					<input type="radio" name="<?php echo $this->option_name . '_position' ?>" id="<?php echo $this->option_name . '_position' ?>" value="before">
					<?php _e( 'Before the content', 'david-scroller' ); ?>
				</label>
				<br>
				<label>
					<input type="radio" name="<?php echo $this->option_name . '_position' ?>" value="after">
					<?php _e( 'After the content', 'david-scroller' ); ?>
				</label>
			</fieldset>
		<?php
	}
	*/
	
	/**
	 * Sanitize the text position value before being saved to database
	 *
	 * @param  string $position $_POST value
	 * @since  1.0.0
	 * @return string           Sanitized value
	 *
	public function david_scroller_sanitize_position( $position ) {
		if ( in_array( $position, array( 'before', 'after' ), true ) ) {
	        return $position;
	    }
	}
	*/
	
	/**
	 * Render the treshold day input for this plugin
	 *
	 * @since  1.0.0
	 */
	public function david_scroller_key_cb() {
		echo '<input type="text" name="' . $this->option_name . '_key' . '" id="' . $this->option_name . '_key' . '"> ';
		
		$key = get_option( $this->option_name . '_key' );
// 		echo '<input type="text" name="' . $this->option_name . '_key' . '" id="' . $this->option_name . '_key' . '" value="' . $key . '"> ';
		
// 		var_dump(get_option( $this->option_name . '_key' ));
		
		
		//var_dump($key);
		
		
		$options = get_option( $this->option_name . '_key' );
		var_dump($options);
		
		
// 		var_dump($this->option_name . '_key');
		
	}
	
	
	
	
	
	
}
